jolly has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/osmo-bsc/+/41361?usp=email )


Change subject: Add ER-GSM band support
......................................................................

Add ER-GSM band support

ER-GSM band expands the R-GSM band by additional 15 channels, starting
from channel 940.

Change-Id: I0a9a2f64d9db65967699453c26ae282c4ddf4558
---
M src/osmo-bsc/bts.c
M src/osmo-bsc/system_information.c
2 files changed, 11 insertions(+), 11 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bsc refs/changes/61/41361/1

diff --git a/src/osmo-bsc/bts.c b/src/osmo-bsc/bts.c
index 2cc6153..77721fb 100644
--- a/src/osmo-bsc/bts.c
+++ b/src/osmo-bsc/bts.c
@@ -525,9 +525,9 @@
                }
                break;
        case GSM_BAND_900:
-               if ((bts->c0->arfcn > 124 && bts->c0->arfcn < 955) ||
+               if ((bts->c0->arfcn > 124 && bts->c0->arfcn < 940) ||
                    bts->c0->arfcn > 1023) {
-                       LOGP(DNM, LOGL_ERROR, "(bts=%u) GSM900 channel (%u) 
must be between 0-124, 955-1023.\n",
+                       LOGP(DNM, LOGL_ERROR, "(bts=%u) GSM900 channel (%u) 
must be between 0-124, 940-1023.\n",
                             bts->nr, bts->c0->arfcn);
                        return -EINVAL;
                }
diff --git a/src/osmo-bsc/system_information.c 
b/src/osmo-bsc/system_information.c
index b438a49..41c7b81 100644
--- a/src/osmo-bsc/system_information.c
+++ b/src/osmo-bsc/system_information.c
@@ -545,8 +545,8 @@
        /* Check presence of E-GSM ARFCN 0 */
        if (pgsm && bitvec_get_bit_pos(bv, 0) == ONE)
                pgsm = false;
-       /* Check presence of R-GSM / E-GSM ARFCNs 955..1023 */
-       for (i = 955; pgsm && i <= 1023; i++) {
+       /* Check presence of R-GSM / E-GSM ARFCNs 940..1023 */
+       for (i = 940; pgsm && i <= 1023; i++) {
                if (bitvec_get_bit_pos(bv, i) == ONE)
                        pgsm = false;
        }
@@ -577,22 +577,22 @@
                /* count the arfcns we want to carry */
                arfcns += 1;

-               /* 955..1023 < 0..885 */
+               /* 940..1023 < 0..885 */
                if (min < 0)
                        min = i;
-               if (i >= 955 && min < 955)
+               if (i >= 940 && min < 940)
                        min = i;
-               if (i >= 955 && min >= 955 && i < min)
+               if (i >= 940 && min >= 940 && i < min)
                        min = i;
-               if (i < 955 && min < 955 && i < min)
+               if (i < 940 && min < 940 && i < min)
                        min = i;
                if (max < 0)
                        max = i;
-               if (i < 955 && max >= 955)
+               if (i < 940 && max >= 940)
                        max = i;
-               if (i >= 955 && max >= 955 && i > max)
+               if (i >= 940 && max >= 940 && i > max)
                        max = i;
-               if (i < 955 && max < 955 && i > max)
+               if (i < 940 && max < 940 && i > max)
                        max = i;
        }


--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/41361?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings?usp=email

Gerrit-MessageType: newchange
Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I0a9a2f64d9db65967699453c26ae282c4ddf4558
Gerrit-Change-Number: 41361
Gerrit-PatchSet: 1
Gerrit-Owner: jolly <[email protected]>

Reply via email to